@@ -500,18 +500,16 @@ class DyffSchemaBaseModel(DyffBaseModel):
     """
 
     @pydantic.model_validator(mode="after")
-    def _ensure_datetime_timezone_utc(cls, values):
-        for field_name, field_value in values.__dict__.items():
+    def _ensure_datetime_timezone_utc(self):
+        for field_name, field_value in self.__dict__.items():
             if isinstance(field_value, datetime):
                 if field_value.tzinfo is None:
                     # Set UTC timezone for naive datetime
-                    setattr(
-                        values, field_name, field_value.replace(tzinfo=timezone.utc)
-                    )
+                    setattr(self, field_name, field_value.replace(tzinfo=timezone.utc))
                 elif field_value.tzinfo != timezone.utc:
                     # Convert to UTC timezone
-                    setattr(values, field_name, field_value.astimezone(timezone.utc))
-        return values
+                    setattr(self, field_name, field_value.astimezone(timezone.utc))
+        return self
 
 
 class JsonMergePatchSemantics(DyffSchemaBaseModel):
