@@ -27,6 +27,7 @@ from .platform import (
     AnalysisRequestBase,
     AnalysisScope,
     ChallengeContent,
+    ChallengeSubmissionBase,
     ChallengeTaskBase,
     ConcernBase,
     DatasetBase,
@@ -148,6 +149,12 @@ class ChallengeCreateRequest(DyffEntityCreateRequest):
     )
 
 
+class ChallengeSubmissionCreateRequest(
+    DyffEntityCreateRequest, ChallengeSubmissionBase
+):
+    pass
+
+
 class ChallengeTaskCreateRequest(DyffEntityCreateRequest, ChallengeTaskBase):
     pass
 
@@ -398,6 +405,10 @@ class AuditQueryRequest(DyffEntityQueryRequest):
     name: Optional[str] = pydantic.Field(default=None)
 
 
+class ChallengeQueryRequest(DyffEntityQueryRequest):
+    pass
+
+
 class DatasetQueryRequest(DyffEntityQueryRequest):
     name: Optional[str] = pydantic.Field(default=None)
 
@@ -492,6 +503,8 @@ __all__ = [
     "AuditQueryRequest",
     "ChallengeContentEditRequest",
     "ChallengeCreateRequest",
+    "ChallengeQueryRequest",
+    "ChallengeSubmissionCreateRequest",
     "ChallengeTaskCreateRequest",
     "ChallengeTaskRulesEditRequest",
     "ChallengeTeamCreateRequest",
